package com.ehsure.ehsurepdaplugin;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.text.TextUtils;
import android.util.Log;

import androidx.annotation.NonNull;

import org.json.JSONException;
import org.json.JSONObject;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BasicMessageChannel;
import io.flutter.plugin.common.StringCodec;

/**
 * EhsurePdaPlugin
 */
public class EhsurePdaPlugin implements FlutterPlugin, ActivityAware {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private BasicMessageChannel<String> mScannerChannel;
    private Activity activity;
    private String action;
    private String extra;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        mScannerChannel = new BasicMessageChannel<>(flutterPluginBinding.getBinaryMessenger(), "ehsure_pda_plugin", StringCodec.INSTANCE);
        mScannerChannel.setMessageHandler((message, reply) -> {
            if (TextUtils.isEmpty(message)) {
                reply.reply("pda config json is empty");
                return;
            }
            try {
                JSONObject jsonObject = new JSONObject(message);
                action = jsonObject.getString("action");
                extra = jsonObject.getString("extra");
                IntentFilter intentFilter = new IntentFilter(action);
                activity.registerReceiver(scannerReceiver, intentFilter);
                reply.reply("PDA connection successful");
            } catch (JSONException e) {
                reply.reply("ACTION and EXTRA mast be required");
                e.printStackTrace();
            }
        });
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        mScannerChannel.setMessageHandler(null);
    }

    private BroadcastReceiver scannerReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            if (TextUtils.equals(action, intent.getAction())) {
                if (intent.hasExtra(extra)) {
                    String message = intent.getStringExtra(extra);
                    mScannerChannel.send(message, reply -> Log.d("scanValue", reply));
                }
            }
        }
    };

    @Override
    public void onAttachedToActivity(ActivityPluginBinding binding) {
        activity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding) {

    }

    @Override
    public void onDetachedFromActivity() {
        activity.unregisterReceiver(scannerReceiver);
    }
}
